Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(404)

Unified Diff: test/cctest/test-assembler-arm64.cc

Issue 271543004: Reland - Arm64: Ensure that csp is always aligned to 16 byte values even if jssp is not. (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Change test-assembler-arm64 PushPopJsspSimpleHelper to disallow ip0 and ip1 instead of x8 and x9 Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/v8globals.h ('k') | test/cctest/test-code-stubs-arm64.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: test/cctest/test-assembler-arm64.cc
diff --git a/test/cctest/test-assembler-arm64.cc b/test/cctest/test-assembler-arm64.cc
index 25f3adb502da94019ff3565101559016173d9311..1ce900b3f3e90b6a78727d1a64d4ea40867818df 100644
--- a/test/cctest/test-assembler-arm64.cc
+++ b/test/cctest/test-assembler-arm64.cc
@@ -8384,10 +8384,10 @@ static void PushPopJsspSimpleHelper(int reg_count,
START();
// Registers x8 and x9 are used by the macro assembler for debug code (for
// example in 'Pop'), so we can't use them here. We can't use jssp because it
// will be the stack pointer for this test.
- static RegList const allowed = ~(x8.Bit() | x9.Bit() | jssp.Bit());
+ static RegList const allowed = ~(ip0.Bit() | ip1.Bit() | jssp.Bit());
rmcilroy 2014/05/09 11:18:46 One last change required here - I think this is a
jbramley 2014/05/09 11:23:51 We used x8/x9 _and_ ip0/ip1: ip0/ip1 were for gene
rmcilroy 2014/05/09 11:30:56 The reason this fails now without this change is b
@@ -8384,10 +8384,10 @@ static void PushPopJsspSimpleHelper(int reg_count,
START();
- // Registers x8 and x9 are used by the macro assembler for debug code (for
+ // Registers ip0 and ip1 are used by the macro assembler for debug code (for
// example in 'Pop'), so we can't use them here. We can't use jssp because it
// will be the stack pointer for this test.
if (reg_count == kPushPopJsspMaxRegCount) {
reg_count = CountSetBits(allowed, kNumberOfRegisters);
}
« no previous file with comments | « src/v8globals.h ('k') | test/cctest/test-code-stubs-arm64.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698